==> fp-ts-contrib-0.1.21.tgz: package/es6/RegExp.js <==
/**
 * Provides regular expression matching.
 *
 * Adapted from https://hackage.haskell.org/package/regex-compat-0.95.1/docs/Text-Regex.html
 *
 * @since 0.1.8
 */
import * as O from 'fp-ts/es6/Option';
/**
 * Returns the list of subexpression matches, or `None` if the match fails.
 *
 * @example
 * import * as O from 'fp-ts/Option'
 * import { match } from 'fp-ts-contrib/RegExp'
 * import { pipe } from 'fp-ts/function'
 *
 * const myMatch = match(/^(\d)(\w)$/)
 * assert.deepStrictEqual(pipe('2e', myMatch, O.map(Array.from)), O.some(['2e', '2', 'e']))
 * assert.deepStrictEqual(myMatch('foo'), O.none)
 *
 * @since 0.1.8
 */
export var match = function (r) { return function (s) { return O.fromNullable(s.match(r)); }; };
/**
 * Returns `true` if the string matches the regular expression,
 * otherwise `false`.
 *
 * @example
 * import { test } from 'fp-ts-contrib/RegExp'
 *
 * const myTest = test(/^(\d)(\w)$/)
 * assert.strictEqual(myTest('6s'), true)
 * assert.strictEqual(myTest('bar'), false)
 *
 * @since 0.1.8
 */
export var test = function (r) { return function (s) { return r.test(s); }; };
/**
 * Replaces every occurance of the given regular expression
 * with the replacement string.
 *
 * @example
 * import { sub } from 'fp-ts-contrib/RegExp'
 *
 * const sanitiseSpaces = sub(/\s/g, '_')
 * assert.strictEqual(sanitiseSpaces('foo bar owl'), 'foo_bar_owl')
 *
 * @since 0.1.8
 */
export var sub = function (r, replacement) { return function (s) {
    return s.replace(r, replacement);
}; };
/**
 * Splits a string based on a regular expression. The regular expression
 * should identify one delimiter.
 *
 * @example
 * import { split } from 'fp-ts-contrib/RegExp'
 *
 * const splitByHash = split(/#/)
 * assert.deepStrictEqual(splitByHash('foo#bar#beer'), ['foo', 'bar', 'beer'])
 * assert.deepStrictEqual(splitByHash('noHashes'), ['noHashes'])
 *
 * @since 0.1.8
 */
export var split = function (r) { return function (s) { return s.split(r); }; };

==> fp-ts-contrib-0.1.23.tgz: package/es6/RegExp.js <==
/**
 * Provides regular expression matching.
 *
 * Adapted from https://hackage.haskell.org/package/regex-compat-0.95.1/docs/Text-Regex.html
 *
 * @since 0.1.8
 */
import * as O from 'fp-ts/es6/Option';
/**
 * Returns the list of subexpression matches, or `None` if the match fails.
 *
 * @example
 * import * as O from 'fp-ts/Option'
 * import { match } from 'fp-ts-contrib/RegExp'
 * import { pipe } from 'fp-ts/function'
 *
 * const myMatch = match(/^(\d)(\w)$/)
 * assert.deepStrictEqual(pipe('2e', myMatch, O.map(Array.from)), O.some(['2e', '2', 'e']))
 * assert.deepStrictEqual(myMatch('foo'), O.none)
 *
 * @since 0.1.8
 */
export var match = function (r) { return function (s) { return O.fromNullable(s.match(r)); }; };
/**
 * Returns `true` if the string matches the regular expression,
 * otherwise `false`.
 *
 * @example
 * import { test } from 'fp-ts-contrib/RegExp'
 *
 * const myTest = test(/^(\d)(\w)$/)
 * assert.strictEqual(myTest('6s'), true)
 * assert.strictEqual(myTest('bar'), false)
 *
 * @since 0.1.8
 */
export var test = function (r) { return function (s) {
    var lastIndex = r.lastIndex;
    var res = r.test(s);
    r.lastIndex = lastIndex;
    return res;
}; };
/**
 * Replaces every occurance of the given regular expression
 * with the replacement string.
 *
 * @example
 * import { sub } from 'fp-ts-contrib/RegExp'
 *
 * const sanitiseSpaces = sub(/\s/g, '_')
 * assert.strictEqual(sanitiseSpaces('foo bar owl'), 'foo_bar_owl')
 *
 * @since 0.1.8
 */
export var sub = function (r, replacement) { return function (s) {
    return s.replace(r, replacement);
}; };
/**
 * Splits a string based on a regular expression. The regular expression
 * should identify one delimiter.
 *
 * @example
 * import { split } from 'fp-ts-contrib/RegExp'
 *
 * const splitByHash = split(/#/)
 * assert.deepStrictEqual(splitByHash('foo#bar#beer'), ['foo', 'bar', 'beer'])
 * assert.deepStrictEqual(splitByHash('noHashes'), ['noHashes'])
 *
 * @since 0.1.8
 */
export var split = function (r) { return function (s) { return s.split(r); }; };
